#
# spec file for package python-sip6
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sip6
Version:        6.7.9
Release:        2.3
Summary:        A Python bindings generator for C/C++ libraries
License:        GPL-2.0-only OR GPL-3.0-only OR SUSE-SIP
Group:          Development/Libraries/Python
URL:            https://www.riverbankcomputing.com/software/sip
Source0:        https://files.pythonhosted.org/packages/source/s/sip/sip-%{version}.tar.gz
Patch0:         support-python3.6.patch
BuildRequires:  %{python_module devel >= 3.6}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module ply}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tomli if %python-base < 3.11}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros

%python_subpackages

%description
SIP is a collection of tools that makes it very easy to create Python
bindings for C and C++ libraries. It was originally developed in 1998
to create PyQt, the Python bindings for the Qt toolkit, but can be used
to create bindings for any C or C++ library. For example it is also used
to generate wxPython, the Python bindings for wxWidgets.

%package devel
Summary:        A Python bindings generator for C/C++ libraries
Group:          Development/Libraries/Python
Requires:       c++_compiler
Requires:       python-devel >= 3.6
%if %{python_version_nodots} <= 36
Requires:       python-dataclasses
%endif
Requires:       python-packaging
Requires:       python-ply
Requires:       python-setuptools
Requires:       (python-tomli if python-base < 3.11)
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      python-sip-impl
# boo#1190441: remove erroneously created non-devel python3X-sip metapackages.
# In order not to remove SIPv4 and possible future packages, we have to explicitly
# name the only version which made it into Factory.
Obsoletes:      python-sip = 6.1.1
Provides:       python-sip-devel = %{version}-%{release}
Provides:       python-sip-impl = %{version}-%{release}

%description devel
SIP is a collection of tools that makes it very easy to create Python
bindings for C and C++ libraries. It was originally developed in 1998
to create PyQt, the Python bindings for the Qt toolkit, but can be used
to create bindings for any C or C++ library. For example it is also used
to generate wxPython, the Python bindings for wxWidgets.

This package contains all the developer tools you need to create your
own sip bindings.

%if 0%{?suse_version} > 1500
%package -n python-sip6-doc
Summary:        A Python bindings generator for C/C++ libraries -- common documentation
Group:          Development/Libraries/Python
Provides:       %{python_module sip6-doc = %{version}-%{release}}

%description -n python-sip6-doc
SIP is a tool that makes it very easy to create Python bindings for C
and C++ libraries. It was originally developed to create PyQt, the
Python bindings for the Qt toolkit, but can be used to create bindings
for any C or C++ library.

This package contains the documentation and example files.
%endif

%prep
%autosetup -p1 -n sip-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/sip-build
%python_clone -a %{buildroot}%{_bindir}/sip-distinfo
%python_clone -a %{buildroot}%{_bindir}/sip-install
%python_clone -a %{buildroot}%{_bindir}/sip-module
%python_clone -a %{buildroot}%{_bindir}/sip-sdist
%python_clone -a %{buildroot}%{_bindir}/sip-wheel
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%fdupes -s doc

%post devel
%python_install_alternative sip-build sip-distinfo sip-install sip-module sip-sdist sip-wheel

%postun devel
%python_uninstall_alternative sip-build

%files %{python_files devel}
%license LICENSE*
%python_alternative %{_bindir}/sip-build
%python_alternative %{_bindir}/sip-distinfo
%python_alternative %{_bindir}/sip-install
%python_alternative %{_bindir}/sip-module
%python_alternative %{_bindir}/sip-sdist
%python_alternative %{_bindir}/sip-wheel
%{python_sitearch}/sipbuild
%{python_sitearch}/sip-%{version}*-info

%if 0%{?suse_version} > 1500
%files -n python-sip6-doc
%license LICENSE*
%doc doc/
%endif

%changelog
* Thu May 25 2023 Dirk Müller <dmueller@suse.com>
- for SLE15, package documentation in devel package
* Mon Apr 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 6.7.9
  * The latest version of ABI v13 is v13.5.1.
  * The latest version of ABI v12 is v12.12.1.
  * Bug fixes.
- Release v6.7.8 4th April 2023
  * The latest version of ABI v13 is v13.5.0.
  * The latest version of ABI v12 is v12.12.0.
  * The 'wheel-includes' value of the 'tool.sip.project' section of
    pyproject.toml now supports the use of absolute file patterns.
  * Replaced the use of the 'toml' package with the standard library 'tomllib'
    package for Python v3.11 and later, and the 'tomli' package for earlier
    versions of Python.
  * Bug fixes.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Feb  9 2023 Ben Greiner <code@bnavigator.de>
- Update to 6.7.7
  * bug-fix release
  * Refactored the handling of composite classes so that they are
    populated properly.
  * Changes to the XML generation to reduce differences to earlier
    versions.
* Wed Feb  1 2023 Ben Greiner <code@bnavigator.de>
- Revert to 6.7.5
  * breaks Qt import in PyQt5
  * https://www.riverbankcomputing.com/pipermail/pyqt/2023-January/045137.html
* Sun Jan 29 2023 Ben Greiner <code@bnavigator.de>
- Update to 6.7.6
  * Minor bug-fix release
  * The latest version of ABI v13 is v13.4.1.
  * The latest version of ABI v12 is v12.11.1.
  * Significantly reduced the memory requirements.
* Thu Jan 12 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to support python 3.6 needed by SLE15:
  * support-python3.6.patch
* Wed Jan 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 6.7.5
  * This is a minor bug-fix release that fixes a problem with
    extract filenames that contain Windows drive letters.
- Version 6.7.4 is a minor big fix release that fixes the typo
  affecting type hints for properties.
- Drop sip-hg2860-fixprop.patch
* Mon Oct 31 2022 Ben Greiner <code@bnavigator.de>
- Add sip-hg2860-fixprop.patch
  * https://www.riverbankcomputing.com/hg/sip/rev/2157850bf018
  * https://www.riverbankcomputing.com/pipermail/pyqt/2022-October/045021.html
* Sat Oct 29 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.7.3
  * This is a very minor bug-fix release but also continues the
    progress of porting the C code to Python.
* Wed Oct 12 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.7.2
  * Bug fixes
  * Refactored the structure to create the outputs module.
  * The Python .api generation now produces the same results as the
    old C++ code
  * Established a pattern for class-based object formatters.
  * Fixed a regression in instantiating class templates.
* Wed Oct  5 2022 Ben Greiner <code@bnavigator.de>
- Update to version 6.7.1
  * Bug fixes
- Drop sip-6.7.0-zipstrict.patch
* Mon Oct  3 2022 Ben Greiner <code@bnavigator.de>
- Update to version 6.7.0
  * Added the /NoAssignmentOperator/, /NoCopyCtor/ and
    /NoDefaultCtor/ mapped type annotations.
  * Added the --generator-version command line option to
    sip-distinfo.
  * Added the 'generator_version' argument to
    Project.get_sip_distinfo_command_line().
  * The resolver/transform stage has been replaced with a pure
    Python implementation.
  * Bug fixes.
- Add sip-6.7.0-zipstrict.patch
  * https://www.riverbankcomputing.com/pipermail/pyqt/2022-October/044927.html
* Mon Jun 20 2022 Ben Greiner <code@bnavigator.de>
- Update to version 6.6.2
  * Enums created with ABI v13 now handle unexpected values by
    creating corresponding pseudo-members.
  * Any config settings passed by a PEP 571 frontend are now used.
  * The 'array' type is now accessible from the sip module.
  * 'array' can now create one dimensional arrays of wrapped types
    that can be modified in situ.
  * Arguments using the /Array/ (and /ArraySize/) annotations will
    now accept 'array' objects of the corresponding type.
  * The latest version of ABI v13 is v13.4.0.
  * The latest version of ABI v12 is v12.11.0.
  * Bug fixes.
* Wed Apr 13 2022 Ben Greiner <code@bnavigator.de>
- Update to version 6.6.1
  * Python v3.6 is no longer supported.
  * The .sip file parser (created using flex and bison) has been
    replaced with a pure Python implementation using PLY.
  * The latest version of ABI v13 is v13.3.1.
  * The latest version of ABI v12 is v12.10.1.
* Sat Feb  5 2022 Ben Greiner <code@bnavigator.de>
- Update to version 6.5.1
  * Added the --no-compile command line option to sip-build.
  * Added the --no-version-info command line option to sip-build.
  * The latest version of ABI v13 is v13.2.1.
  * The latest version of ABI v12 is v12.9.1.
  * Bug fixes.
* Fri Dec  3 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.5.0
  * Added 'UIntEnum' as a value of the /BaseType/ enum annotation
    to support enum.IntEnum types with unsigned values.
  * The latest version of ABI v13 is v13.2.0.
  * Bug fixes.
* Fri Oct 29 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.4.0
  * Added support for the 'py_ssize_t_clean' argument to the
    '%%Module' directive.
  * Bug fixes.
* Sat Oct 16 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.3.1
  * Bug fixes.
  * SIP itself now uses the limited API itself.
  * Added the Project.get_platform_tag() method to the sipbuild
    API.
* Sun Oct  3 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.2.0
  * The interpreter tag in the name of a wheel now specifies
    a minimum Python version (rather than each supported
    Python version) when the limited API is used.
  * The /PyQtNoQMetaObject/ annotation can now be applied to
    namespaces.
  * sip-build, sip-install and sip-wheel now support the
  - -disabled-feature command line option.
  * Added support for Python v3.10.
  * Added the setuptools builder which is the default for
    Python v3.10 and later.
  * The ABI version, wherever specified, is now a minimum
    version with a default minor version of 0.
* Mon Sep 13 2021 Ben Greiner <code@bnavigator.de>
- Obsolete erroneously created non-devel metapackage -- boo#1190441
* Tue Jun 15 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.1.1
  * The abi-version project option is interpreted as a minimum
    version rather than an exact version.
  * Bug fixes.
* Thu May 13 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.1.0
  * Added support for the noexcept specifier. This has the same
    effect as a throw specifier that has no arguments.
  * throw specifiers in .sip files are now ignored when using ABI
    v13.1 or later and v12.9 or later.
  * Added the scripts-dir project option for specifying the
    directory where scripts are installed. There is a
    corresponding --scripts-dir command line option to sip-build
    and sip-install.
  * The build tools (sip-build, sip-install, sip-sdist and
    sip-wheel) may now be invoked using the -m command line option
    of the Python interpreter.
  * If C++ exceptions are used then a C++11 compiler is required.
  * The latest version of ABI v13 is v13.1.0.
  * The latest version of ABI v12 is v12.9.0.
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.0.3
  * Bug fixes.
* Thu Feb 25 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.0.2
  * Bug fixes.
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Rename to python-sip6
- Update to version 6.0.1
  * The latest version of ABI v13 is v13.0.1.
  * Bug fixes.
- NEWS for v6.0.0
  * All features deprecated in SIP v5 have been removed.
  * Added ABI v13.0 of the sip module.  This uses the Python
    enum module to implement all enums.
  * Added support for mapped type convertors to have
    additional user-defined state.  This is implemented
    using the %%ReleaseCode directive, the SIP_USER flag and
    the sipConvertToTypeUS(), sipForceConvertToTypeUS() and
    sipReleaseTypeUS() API functions.  (ABI v13 only.)
  * %%ConvertFromTypeCode and %%ConvertToTypeCode are now
    optional for mapped types.
  * Added support for the SIP_PYENUM additional SIP type.
  * Added and sipIsEnumFlag()
  * Added the /BaseType/ enum annotation for specifying the
    exact Python enum type to be used.  (ABI v13 only.)
  * Added support for wrapping named unions.
  * Added support for Py_hash_t.  (ABI v13 only.)
  * Python names automatically have a '_' appended if they
    are Python keywords.
  * The lexer can now handle '\xNN' characters.
  * sip.pyi and py.typed are automatically installed if
    dunder-init is specified and pep484-pyi is specified for
    at least one module.
* Tue Nov 24 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 5.5.0
  * Added the 'exceptions', 'extra_compile_args', 'extra_link_args'
    and 'extra_objects' attributes to the 'Buildable' class with
    corresponding bindings options.
  * The 'abi-version' project option and the '--abi-version' of
    sip-module can now specify a major version only (as opposed to
    a major.minor version) to select the latest ABI with that major
    version number.
* Mon Nov 16 2020 Benjamin Greiner <code@bnavigator.de>
- Fix files section for doc subpackage because python-rpm-macros
  becomes stricter gh#openSUSE/python-rpm-macros#66
* Mon Nov 16 2020 Benjamin Greiner <code@bnavigator.de>
- Don't provide or obsolete the python-sip package in -devel
* Thu Nov  5 2020 Benjamin Greiner <code@bnavigator.de>
- dropped patches: disable-rpaths.diff disable-strip.diff not
  applicable to SIP5 codebase
* Sun Oct 25 2020 Benjamin Greiner <code@bnavigator.de>
- Fix for multiple python3 flavors gh#openSUSE/python-rpm-macros#64
- clean up alternatives: use %%python_clone -a
- only make install in siplib for PyQt4.sip and PyQt5.sip libraries
* Mon Aug 31 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.4.0
  * The latest version of the module ABI is v12.8.1.
  * Python v3.9 is supported.
  * Added support for building the sip module for PyPy.
  * Added the 'distinfo' project option to allow the creation of a .dist-info
    directory to be disabled.  sip-install has a corresponding '--no-distinfo'
    command line option.
  * Added 'SIP_VERSION' and 'SIP_VERSION_STR' to the 'sipbuild' module API.
  * Bug fixes.
- Legacy sip4 is now in python-sip4 package
* Fri Aug 28 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.3.0
  * The latest version of the module ABI is v12.8.0.
  * Added the 'get_metadata_overrides()' and 'get_sip_distinfo_command_line()'
    methods to the 'Project' class, and the '--metadata' command line option to
    sip-distinfo.  Together they allow a project.py script to override any
    PEP 566 metadata values specified in the pyproject.toml file.
  * Added the 'gui-scripts' project option to specify a list of GUI entry
    points to create.  sip-distinfo has a corresponding '--gui-script' command
    line option.
  * Added the 'minimum-macos-version' project option to specify the minimum
    version of macOS supported by the project.
- Changelogs of intermediate releases:
  v5.2.0 released 10th April 2020
  * Added the 'manylinux' project option to disable the support for 'manylinux'
    part of the platform tag to be used in the name of a wheel.  sip-wheel has
    a corresponding '--no-manylinux' command line option.
  * Added the 'wheels-include' project option to specify additional files and
    directories to be included in a wheel.
  v5.1.2 released 3rd April 2020
  * The latest version of the module ABI is v12.7.2.
  * The examples are now included in the sdist.
  * Bug fixes.
  v5.1.1 released 31st January 2020
  * Bug fixes.
  v5.1.0 released 6th January 2020
  * Added the 'minimum-glibc-version' project option to specify the minimum
    GLIBC version required by the project.  This is used to determine the
    correct platform tag to use for Linux wheels.
  * Added the 'build-tag' project option to specify the build tag to be used in
    the name of a wheel.  sip-wheel has a corresponding '--build-tag' command
    line option.
  * The values of list options in pyproject.toml files can now contain
    environment markers as defined in PEP 508.
  * Added Project.project_path() to the API.
  released v5.0.1 19th December 2019
  * Bug fixes.
  releasesd v5.0.0 4th October 2019
  * The release of SIP v5.
- The new major release uses Python setuptools
  * Allows to simplify the specfile tremendously
  * The abi macros and python-sip(api) are now provided by python-qt5-sip
  * Remove -common and -devel package.
* Thu Aug 27 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 4.19.24
  * Added support for Python v3.9.
  * %%InstanceCode is now used to provide the default result of
    virtual handlers that return a class or mapped type by value.
  * 'android_abi' can now be used in a configuration file when
    building the sip module using qmake.  This is required when
    using Qt v5.14 or later on Android.
- all intermediate versions are tagged "minor bug-fix release"
- refresh disable-strip.diff
* Fri Sep 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.19.19
  * Correction to the docs.
  * Added sipIsOwnedByPython(), sipRegisterExitNotifier() and
    sipVisitWrappers() to the public API.
  * Deprecated the -B option to sip.
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.19.18
  * Define SIP_NULLPTR as NULL (rather than 0)
  * Updated the docs regarding sip5.
  * Fixed warnings triggered by Python v3.8.
  * Don't try and acquire the GIL if the interpreter is no longer there.
* Mon Jun  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.19.17. Check the ChangeLog file for the list of changes.
* Thu Apr 18 2019 Todd R <toddrme2178@gmail.com>
- Update to 4.19.16
  * Further fixes for diamond class hierarchies.
  * Don't cast to a class that occurs more than once in a super-class hierarchy.
  * Added support for the haiku platform.
  * Updated the docs and roadmap for SIP v5.
* Wed Apr 17 2019 Todd R <toddrme2178@gmail.com>
- Package .dist-info directory.  The bugs with it have been fixed
  and some packages require it in order to properly detect that
  sip is installed.
* Sat Apr  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.19.15
  * Fixed a code generation regression specific to PyQt4.
  * Fixed the handling of duplicate classes in an MRO
  * Fixed the handling of size_t as a template argument.
  Check https://www.riverbankcomputing.com/static/Downloads/sip/4.19.15/ChangeLog
  for the complete changelog
- Drop fix_qt4_code_gen.patch. Merged upstream
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Add fix_qt4_code_gen.patch
  Fixes python-qt4 building.  Should be in next upstream release.
  See: http://python.6.x6.nabble.com/PyQt4-compilation-error-with-sip-4-19-14-convert-std-nullptr-t-to-int-in-initialization-td5248504.html
  From: https://www.riverbankcomputing.com/hg/sip/rev/7bd4d19479ad
* Wed Feb 13 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to a working location for the tarball
* Tue Feb 12 2019 Mikhail Terekhov <termim@gmail.com>
- Update to 4.19.14:
  * The reference count displayed by sip.dump() now has the same
    caveat as sys.getrefcount().
  * Added SIP_NULLPTR to the C API.
  * Added support for size_t.
  * Added sipLong_AsSizeT() to the C API.
  * Added the '=' format characters to sipBuildResult() and
    sipParseResult().
* Sun Jan  6 2019 wbauer@tmo.at
- Build a private Qt4 module as well, that's needed by the latest
  python-qt4 (boo#1119636)
* Wed Dec 19 2018 Todd R <toddrme2178@gmail.com>
- Use upstream-recommended %%{_rpmconfigdir}/macros.d directory
  for the rpm macros.
* Sun Oct 21 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add disable-strip.diff to fix the -debuginfo creation.
- Update to 4.19.13:
  * Build system fixes
  * Removed support in the XML/API export for deprecated features
  * Pass the fully qualified Python names of types for arguments and
    results.
  * Various fixes for the XML export
  * Fixed a bug when arguments that were templates could lose their type
    hints
* Mon Jul  2 2018 christophe@krop.fr
- Update to 4.19.12:
  * Added the /ScopesStripped/ argument annotation.
  * The members of traditional C/C++ enums are now also visible within the
    scope of the enum itself. This means that members of scoped and unscoped
    enums can be accessed in the same way from Python.
  * Private copies of the sip module are now easier to configure and use.
    SIP v5 will only support private copies.
  * Added the -n option to the sip code generator to support private copies of
    the sip module.
  See https://www.riverbankcomputing.com/static/Downloads/sip/ChangeLog for
  the complete changelog.
- Run spec-cleaner
* Fri Apr 13 2018 termim@gmail.com
- Update to version v4.19.8
  - Bug fixes.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to version v4.19.7
  * The %%Docstring directive can now include automatically
    generated signature descriptions using the "signature" option.
  * typedefs can now have %%Docstring directives.
  * Bug fixes.
  version v4.19.6
  * Bug fixes.
  version v4.19.5
  * Bug fixes.
  version v4.19.4
  * Added support for C++11 scoped enums implemented as Python
    enums.
  * Added enableoverflowchecking() to the sip module.
  * Added sipEnableOverflowChecking() to the C API.
  * Added sipTypeIsScopedEnum() to the C API.
  * Added sipConvertToBool() to the C API.
  * Added sipConvertToEnum() to the C API.
  * Deprecated sipCanConvertToEnum() in the C API.
  * Added sipLong_AsChar(), sipLong_AsSignedChar() and
    sipLong_AsUnsignedChar() to the C API.
  * Added sipLong_AsShort() and sipLong_AsUnsignedShort() to the C
    API.
  * Added sipLong_AsInt() and sipLong_AsUnsignedInt() to the C API.
  * Added sipLong_AsLong() and sipLong_AsUnsignedLong() to the C
    API.
  * Added sipLong_AsLongLong() and sipLong_AsUnsignedLongLong() to
    the C API.
  * Bug fixes.
* Wed Nov 15 2017 mimi.vx@gmail.com
- fix have_python conditions
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to 4.19.3
  * Added support for type hints for properties.
  * Added sipEventType and sipRegisterEventHandler() to the C API.
  * Added sipInstanceDestroyed() to the C API.
  * Added sipPrintObject() to the C API.
  * Bug fixes.
* Mon May 15 2017 toddrme2178@gmail.com
- Provide a basic api version macro
* Sat Apr  8 2017 hpj@urpla.net
- Update to 4.19.2
  * siplib/siplib.c.in: Remove an unnecessary comment.
  * siplib/siplib.c.in:
    Fixed a crash when a user defined class uses sip.wrappertype as it's
    meta-type but is not derived from sip.simplewrapper.
* Mon Apr  3 2017 hpj@urpla.net
- Fix requires_python3_sip_api macro
* Wed Mar 29 2017 toddrme2178@gmail.com
- Fix Provides macro.
- Split largest part of docs into own subpackage to reduce package
  size.
* Sat Mar 11 2017 toddrme2178@gmail.com
- Fix sip api macro.
- Fix header location.
- Compile and install .pyc files.
* Wed Mar  8 2017 toddrme2178@gmail.com
- spec file cleanups
- better use of multipython macros
- include more documentation
* Mon Mar  6 2017 toddrme2178@gmail.com
- Add shared data directory and corresponding package.
* Wed Mar  1 2017 toddrme2178@gmail.com
- Fix python library handling.
* Mon Feb 27 2017 toddrme2178@gmail.com
- Switch to single spec version.
* Thu Feb 16 2017 termim@gmail.com
- Update to 4.19.1
  * Added the %%PreMethodCode directive.
  * Added sipEnableGC() to the C API.
  * Added the -D command line option so that the generated code is
    aware of Python debug builds.
* Tue Jan  3 2017 termim@gmail.com
- Update to 4.19
  * added the assign() function to the sip module
  * added support for the final keyword
  * added the use_limited_api argument to the %%Module directive
  * added the %%HideNamespace directive.
* Tue Jul 26 2016 termim@gmail.com
- Update to 4.18.1
  * Bug fixes
* Mon Jul  4 2016 hpj@urpla.net
- removed build-compare.diff: it is the default since 4.18 anyway
- disable-rpaths.diff refreshed
* Wed May 11 2016 termim@gmail.com
- Update to 4.18 This implements the automatic generation of PEP 484 type
  hint files. The sip extension module is available as a wheel from PyPi.
  * Added the /TypeHint/ argument, class, mapped type, function, typedef
    and variable annotations.
  * Added the /TypeHintIn/ and /TypeHintOut/ argument, class, mapped type
    and typedef annotations.
  * Added the /TypeHintValue/ argument, class and mapped type annotations.
  * Added the /NoTypeHint/ class, enum, function and variable annotations.
  * Added the %%ExportedTypeHintCode and %%TypeHintCode directives.
  * Added the -f command line option to treat warnings as errors.
  * Added the -y command line option to generated PEP 484 compatible type
    hint stub files.
  * Deprecated the /DocType/ and /DocValue/ annotations.
* Fri Oct 30 2015 termim@gmail.com
- Update to 4.17.0
  * This version adds support for PEP 465, PEP 492 and MSVC 2015.
* Mon Jul 20 2015 termim@gmail.com
- Update to 4.16.9:
  * This is mainly a bug-fix release.
* Sat Jun 13 2015 termim@gmail.com
- Update to 4.16.8:
  * This is mainly a bug-fix release.
- Update to 4.16.7:
  * This is a minor functional and bug-fix release.
- Update to 4.16.6:
  * Added the /FileExtension/ class annotation.
  * Installing into a virtual env should now work.
  * Timestamps are no longer included in generated code. The -T command
    line option is now ignored and deprecated.
  * The @file method of passing additional command line options is now
    supported. The -z command line option is now deprecated.
* Tue Dec 30 2014 hrvoje.senjan@gmail.com
- Update to 4.16.5:
  * Minor functional and bug-fix release.
  - Changes since 4.16.4:
  * Added the /AbortOnException/ function annotation.
  * Added the /DisallowNone/ function annotation.
  * Added the /DisallowNone/ argument annotation.
* Sat Oct 11 2014 termim@gmail.com
- Update to 4.16.3
  - This is a minor functional release including the implementation of
    __qualname__ for class enums.
  - run spec-cleaner
* Thu Jul 31 2014 toddrme2178@gmail.com
- Update to 4.16.2
  - Deprecated the %%ConsolidatedModule directive as it won't be supported in
    SIP v5.
  - Bug fixes.
* Tue Jun 10 2014 termim@gmail.com
- Update to 4.16.1
  - Bug fixes.
* Thu May 29 2014 termim@gmail.com
- Update to 4.16
  - Added the /NoSetter/ variable annotation.
  - Added the -B option to sip.
  - Changed the handling of timelines (introducing a potential incompatibility)
    so that later versions of wrapped libraries can be wrapped so long as they
    are compatible with known versions.
  - Added support for the 'no_receiver_check' argument to connect() in PyQt
    v4.11.
  - Added the --configuration option to configure.py.
  - Added the --sysroot option to configure.py.
  - Added the --target-py-version option to configure.py.
  - Added the --no-tools option to configure.py.
  - Added the --use-qmake option to configure.py.
  - Bug fixes.
* Mon Mar 17 2014 termim@gmail.com
- Update to 4.15.5
  - The use_arch argument of sipconfig.create_wrapper() can now specify a space
    separated set of architectures.
  - Bug fixes.
* Fri Jan 10 2014 lbeltrame@kde.org
- Fix SNAFU in preun scriptlet (missing spaces)
* Thu Jan  9 2014 lbeltrame@kde.org
- New upstream version 4.15.4:
  - Fixed all the compiler warning messages when building the sip module.
  - Fixed the parsing of C++ types involving multiple const and pointers.
  - Added SIP_SSIZE_T_FORMAT to the C API.
  - Moved the lexer and parser meta-source files to a separate directory to avoid
  problems with make accidentaly regenerating them.
  - Allow the pointers used to store the parsed results from Python
  reimplementations to be NULL.
  - Remove the __pycache__ directory when cleaning.
* Sun Oct 20 2013 lbeltrame@kde.org
- Use alternatives for /usr/bin/sip to prevent conflicts between
  Python 3 and Python 2 python-sip-devel packages
* Thu Oct 17 2013 toddrme2178@gmail.com
- update to v4.15.3. This is a bug fix release for a regression
  that affects PyQtChart.
* Thu Sep 19 2013 toddrme2178@gmail.com
- update to v4.15.2. This is a minor functional release that will
  be needed by PyQt v5.1. It also contains bug fixes needed by
  PyKDE4.
* Tue Sep 17 2013 speilicke@suse.com
- Revert sr#79987, moving /usr/bin/sip into python-sip-bin and requiring
  that in python3-sip-devel (plus split provides) only causes trouble. It will
  make python3-sip-devel depend forever on Python2 for absolutely no reason.
  Both python-sip-devel and python3-sip-devel can happily provide /usr/bin/sip
  since the binary is identical. You can have both installed in parallel and
  remove either without breaking anything. (bnc#835161)
* Wed Sep 11 2013 tittiatcoke@gmail.com
- Build issues are resolved with the Python KDE bindings. Return
  to version 4.15.1
* Fri Aug 30 2013 tittiatcoke@gmail.com
- Revert back to version 4,14,7 to prevent crashes in Plasma-desktop
  (bko#323899).
* Tue Aug 27 2013 termim@gmail.com
-  update to 4.15.1. This fixes a regression in v4.15 related to the handling of hidden virtual methods. The regression does not affect PyQt.
-  update to v4.15. This is a significant functional release and required by PyQt v5.0.1 and PyQt v4.10.3.
  - Added the call_super_init argument to the %%Module directive to specify that classes should support cooperative multi-inheritance.
  - Added the %%FinalisationCode directive.
  - Added the /Mixin/ class annotation.
  - Added the /NoScope/ enum annotation.
  - Added sipConvertFromNewPyType() to the C API.
  - Added sipConvertToArray() and sipConvertToTypedArray() to the C API.
  - Added sipRegisterProxyResolver() to the C API.
* Wed Jun 19 2013 dmueller@suse.com
- update to 4.14.7:
  - The internal API version is increased to 10.0 requiring the regeneration of
    all modules.
  - Added the /Sequence/ function annotation.
  - %%ConvertFromTypeCode can now be specified for classes.
  - Added sipEnableAutoconversion() to the C API.
  - Added sipSetDestroyOnExit() to the C API.
  - Bug fixes.
* Mon Apr 22 2013 dmueller@suse.com
- update to 4.14.6:
  * Bug fix
* Wed Mar 27 2013 dmueller@suse.com
- update to 4.14.5 (bnc#812130):
  * Bug fixes (specifically for QGIS)
* Thu Mar  7 2013 mlin@suse.com
- Update to 4.14.4
  * bugfix release
  * include a potential incompatibility in the use of the %%VirtualErrorHandler directive.
* Tue Jan 29 2013 dmueller@suse.com
- update to 4.14.3:
  - The /KeepReference/ argument annotation, when applied to factories, will
    now keep the reference with the object created by the factory.
  - Any object that supports the buffer protocol can now be passed when a
    sip.voidptr is expected.
* Sun Dec  9 2012 lbeltrame@kde.org
- Update to 4.14.2:
  - Added sip.setdestroyonexit().
  - sip.voidptr() will now accept any object that implements the buffer
    protocol.
* Mon Oct 29 2012 dmueller@suse.com
- update to 4.14.1:
  - SIP_PYBUFFER can now be used to define objects that implement the Python
    buffer protocol.
  - Added /Capsule/ typedef annotation.
  - Added the 'z' format character to sipBuildResult().
  - Added the 'z', '!' and '$' format characters to sipParseResult().
  - The C prototype foo(void) is now accepted.
  - sipdistutils.py will now include swig_opts if no sip_opts have been
    defined.
  - Bug fixes.
* Mon Oct  1 2012 einar@heavensinferno.net
- Update to latest upstream version:
  - The internal API version is increased to 9.0 requiring the regeneration
    of all modules.
  - Added the %%InstanceCode directive.
  - Added the %%VirtualErrorHandler directive.
  - Added the default_VirtualErrorHandler argument to the %%Module directive.
  - Added the VirtualErrorHandler class annotation.
  - Added the NoVirtualErrorHandler and VirtualErrorHandler function
    annotations.
  - The AllowNone and NoRelease mapped type annotations can now be used
    with mapped type templates.
  - SIP_PLATFORM_* and SIP_TIMELINE_* preprocessor symbols are generated
    corresponding to the -t arguments passed on the command line.
  - Deprecated sipTransferBreak().
  - For Python v2.x unsigned short and unsigned char (when used as a byte)
    are now converted to int, rather than long, objects.
  - Added support for MSVC 2010 to the build system.
-
* Thu Jul  5 2012 dmueller@suse.com
- install api version as rpm macro
* Fri Jun 22 2012 mlin@suse.com
- Update to version 4.13.3
  * The /NoRaisesPyException/ and /RaisesPyException/ function annotations can
    now be applied to constructors.
  * Added support for the Python v3.3 handling of Unicode.
* Tue Apr 10 2012 asterios.dramis@gmail.com
- Link against libpython. Fixes bnc#756282 and bnc#721280.
- Remove SUSE_ASNEEDED=0 from spec file.
* Fri Mar 23 2012 cfarrell@suse.com
- license update: GPL-2.0 or GPL-3.0 or SUSE-SIP
  Use SUSE- proprietary extension until SIP license is accepted upstream at
  spdx.org
* Mon Feb 20 2012 dmueller@suse.de
  update to 4.13.2:
  - A bug fix release.
* Fri Dec 23 2011 dmueller@suse.de
- update to 4.13.1:
  - Deprecation warnings can no longer be disabled.
  - Added the all_raise_py_exception argument to the %%Module directive.
  - Added the /NoRaisesPyException/ function annotation.
  - Added the /PyName/ typedef annotation.
  - Class templates now allow super-classes to be defined as template
  arguments.
  - Added support for 'public' preceding the name of a class in a super-class
  list.
  - Added support for 'protected' and 'private' preceding the name of a class
  in a super-class list.  Any such super-class will be ignored.
* Thu Oct 27 2011 Sascha.Manns@open-slx.de
- Changelog from the Creators
  - SIP v4.13 has been released. This is a minor feature release.
    o added the %%DefaultDocstringFormat directive
    o added the format argument to the %%Docstring directive
    o %%ConvertToSubClassCode can now cause a restart of the conversion
    process using a different requested type
    o '*' and '&' are now supported as unary operators in expressions
    used in the values of default arguments
    o the /Transfer/ annotation can now be used with the /Array/
    annotation to prevent the freeing of the temporary array of
    pointers.
* Wed Oct 26 2011 Sascha.Manns@open-slx.de
- Updated to 4.13
  - last stable release
* Mon Aug 29 2011 termim@gmail.com
- Add python-sip-bin package to avoid conflicts between python2
  and python3 versions
* Tue Aug 16 2011 termim@gmail.com
- Update to 4.12.4
  - A bug fix release.
* Mon May 30 2011 dmueller@suse.de
- update to 4.12.3:
  - A bug fix release.
* Mon May  2 2011 dmueller@suse.de
- update to 4.12.2:
  * /KeepReference/ is now supported as a function annotation.
  * Handwritten code in class templates no longer have the types
  substituted in lines that appear to contain C preprocessor directives.
  * Added support for global inplace numeric operators.
* Tue Jan 25 2011 dmueller@suse.de
- update to 4.12.1:
  - Added support for the __getattribute__, __getattr__, __setattr__ and
    __delattr__ methods.
  - Added the /RaisesPyException/ function annotation.
  - Added SIP_SSIZE_T as a predefined type.
  - PyObject * can now be used as a synonym for SIP_PYOBJECT.
  - Added sip.ispycreated() to the sip module.
  - Added the --deployment-target flag to configure.py for MacOS/X.
* Mon Dec 27 2010 dmueller@suse.de
- update to 4.12:
  - Implemented the revised directive syntax for %%Module.
  - Deprecated %%CModule, use %%Module instead.
  - Added the keyword_arguments argument to %%Module to specify the level of
    support for Python keyword arguments.
  - Deprecated the -k flag to sip, use the keyword_arguments argument to
    %%Module instead.
  - Added an automatic pseudo-%%Timeline to allow the SIP version number to be
    used in the %%If directive.
  - Changed the behavior of the /KeywordArgs/ annotation to specify the level
    of support for Python keyword arguments.
  - Deprecated the /NoKeywordArgs/ annotation, use /KeywordArgs="All"/ instead.
  - Added the use_argument_names argument to %%Module to provide the real names
    of arguments to handwritten code.
  - Module docstrings are now supported.
  - Added %%AutoPyName to automatically provide Python names.
  - Added %%Property to implement Python properties based on C/C++ getters and
    setters.
  - Added %%Extract to allow arbitrary text to be embedded in specification
    files and subsequently extracted.
  - Deprecated %%Doc and %%ExportedDoc, use %%Extract instead.
  - Added the -X flag to sip to extract text defined with %%Extract.
  - Deprecated the -d flag to sip, use -X instead.
  - Added /PyInt/ as an argument, function and typedef annotation to force
    char types to be handled as Python integers rather that single character
    strings.
  - Added the L and M format characters to sipBuildResult(), sipCallMethod()
    and sipParseResult().
  - Added sipGetAddress().
  - Added the -T flag to sip to suppress the timestamp in the header comments
    of generated files.
  - sip.voidptr now behaves like a Python memoryview object and supports
    sub-script assignment.
  - Added the --sip-module flag to configure.py to allow the name and
    containing package of the sip module to be specified thereby allowing
    packages to include a local copy of the sip module.
* Mon Oct 25 2010 dmueller@suse.de
- update to 4.11.2:
  - /KeepReference/ can now be applied to global functions and static methods.
  - %%TypeCode can now be specified in a %%MappedType directive.
  - Mapped types for templates no longer require the template arguments to be
    fully defined.
  - Build system changes required by PyQt v4.8 and Qt v4.7.
* Fri Oct  1 2010 einar@heavensinferno.net
- update to 4.11.1:
  - A bug fix release.
* Mon Sep  6 2010 coolo@novell.com
- fix python linking for factory
* Wed Sep  1 2010 dmueller@suse.de
- update to 4.11:
  - Added the %%UnitPostIncludeCode directive.
  - /KeepReference/ will now accept a key to track when the same object is
    passed to more than one method.
  - operator() and __call__() can now accept keyword arguments.
  - Added support for Python v3.2.
* Mon Aug 16 2010 dmueller@suse.de
- update to 4.10.5:
  - A bug fix release for Python v3 and Python v2.7.
  - Use capsules when being built for Python v2.7 to work around an apparent
    bug in the support for PyCObject.
  - Added support for Q_SLOT, Q_SLOTS, Q_SIGNAL and Q_SIGNALS.
  - Added the /__len__/ function annotation.
* Tue Jun  8 2010 dmueller@suse.de
- update to 4.10.2:
  - A bug fix release.
* Wed May 19 2010 cmorve69@yahoo.es
- fix build-compare
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.10.1:
  * Added the /NoCopy/ function and argument annotations.
* Fri Jan 15 2010 tittiatcoke@gmail.com
- update to 4.10
  * Added the sip.voidptr.ascapsule() method.
  * Added the -P command line option to build modules with
    "protected" redefined to "public" if supported by the platform.
    This can result in significantly smaller modules.
  * Added the -o command line option to automatically generate docstrings.
  * Added the -k command line option and /KeywordArgs/ and /NoKeywordArgs/
    function annotations to support keyword arguments.
  * Added the /Default/ exception annotation.
  * Added the /DocType/ argument, function, mapped type and variable annotations.
  * Added the /DocValue/ argument annotation.
  * Added the %%Docstring directive to specify explicit docstrings for classes,
    functions and methods.
  * Added sipError to %%MethodCode to allow user errors to be distinguished
    from interpreter errors.
  * Added sipBadCallableArg() to the C API.
  * Added support for configuring and building outside of the source tree.
* Tue Nov 24 2009 hpj@urpla.net
- update to 4.9.3:
  * A bug fix release.
* Fri Nov 20 2009 dmueller@suse.de
- update to 4.9.2:
  * A bug fix release.
* Fri Nov 20 2009 dmueller@suse.de
- add split-provides
* Sat Oct 24 2009 dmueller@suse.de
- update to 4.9.1:
  * A bug fix release.
* Mon Sep 28 2009 dmueller@suse.de
- update to 4.9:
  * support for __iter__ and __next__
  * the %%API directive
  * the /API/ annotation
  * sipIsAPIEnabled() has been added to the C API
  * sip.getapi() and sip.setapi() have been added to the Python API
  * sip.ispyowned() has been added to the Python API
  * mapped types can now act as a namespace for enums and static methods
  * the /Array/ annotation can now be applied to classes and mapped types
  * the /NoArgParser/ annotation can now be applied to methods as well as functions
  * the --arch flag was added to configure.py to specify which MacOS/X architectures are built
  * SIP is now also licensed under the GPL v2 and v3.
* Mon Aug 31 2009 beineri@opensuse.org
- fix plasmoids requiring python-devel to work (part of bnc#535057)
* Tue Aug  4 2009 hpj@urpla.net
- Fixed a crash with sipFindType() when the search happens to land on an
  unresolved external type.
* Thu Jul 30 2009 hpj@urpla.net
- update to 4.8.2:
  - Fixed the '/' operator for Python v3 and future import for Python v2.
  - Backported the /AllowNone/ class annotation from v4.9.
* Mon Jul  6 2009 hpj@urpla.net
- create a separated -devel package and include the nice documentation
* Wed Jun 17 2009 dmueller@suse.de
- update to 4.8.1:
  - Added support for defining a private assignment operator to suppress the
  possible generation of an assignment helper.
* Mon Jun  8 2009 beineri@opensuse.org
- update to 4.8 release:
  * support for Python v3
  * the ability to supply alternate super-types and meta-types
    for wrapped objects
  * documentation built using Sphinx
* Tue Jun  2 2009 dmueller@suse.de
- update to 20090601 snapshot fixing nested template handling
* Sun May 17 2009 beineri@opensuse.org
- update to 4.8 snapshot as of 20090430
* Fri Dec  5 2008 dmueller@suse.de
- update to 4.7.9:
  - Added the /Deprecated/ class and function annotation (based on a patch from
    Lorenzo Berni).
  - Templates now support instance variables and enums.
  - A Python int object can now be used whenever an enum is expected without
    needing to explicitly cast it using the enum's constructor.  The
    /Constrained/ argument annotation can be used to suppress this behaviour.
  - typedef type names are now used in string representations of types (e.g. in
    the names of mapped types) to reflect what the programmer sees rather than
    what the compiler sees.  The /NoTypeName/ typedef annotation can be used to
    suppress this behaviour.
  - The new handling of the typedef names was correctly using the real types for
    virtual handler arguments but not the return values.
* Sun Aug 10 2008 dmueller@suse.de
- update to 4.7.7:
  * C++ structs are now properly handled as a class with
  a default public  section
  * sip.dump() now includes the objects first child wrapper
* Tue May 27 2008 dmueller@suse.de
- update to 4.7.6:
  * generator fixes for being able to bind Qt 4.4
* Wed Feb 13 2008 dmueller@suse.de
- update to 4.7.4:
  * The build system handles the directory structure used by Leopard's Python
    installation.
  * Added support for /Transfer/ as a constructor ann
* Thu Dec 13 2007 dmueller@suse.de
- update to 4.7.3:
  * Added support for automatically generating missing complementary
    comparision operators.  Note that this introduces a potential compatibility
    problem - see the documentation for details.
  * Added the SingleShot argument annotation.
  * Added the TransferThis function annotation.
* Mon Oct  1 2007 stbinner@suse.de
- update to 4.7.1: minor bugfixes
* Fri Aug 17 2007 dmueller@suse.de
- remove conflict as it is now common base for qt 3.x
  and qt 4.x (#300041)
* Sun Aug 12 2007 dmueller@suse.de
- %%py_requires no longer has buildrequires
* Sat Aug 11 2007 dmueller@suse.de
- add conflict against python-qt 3.x versions
* Thu Aug  2 2007 dmueller@suse.de
- update to 4.7:
  * Added %%PickleCode to allow handwritten code to pickle a wrapped C++
    instance or C structure.
  * Added %%CompositeModule to create modules that are composites of ordinary
    modules.
  * Added %%ConsolidatedModule (and the -p command line option) to create
    modules that contain all the wrapper code on behalf of ordinary modules.
  * Added the dump() function to the sip module.
  * Added sipTransferBreak() to the SIP API.
  * Added support for /Transfer/ as a function annotation.
* Wed Apr 11 2007 dmueller@suse.de
- update to 4.6:
  * Added support for wchar_t.
  * The -g command line option releases the GIL whenever a call is made to the
  * wrapped library.
  * Added the /HoldGIL/ annotation to explicitly retain the GIL when calling a
    particular function in the wrapped library.
  * Added sipFindClass() and sipFindNamedEnum() to the public API.
  * /TransferThis/ may be specified more than once.
  * Added support for __truediv__ and __itruediv__.
* Fri Jan 26 2007 dmueller@suse.de
- Initial package (4.5.2)
